==> graphql-web-lite-16.6.0-2.tgz: package/validation/rules/ProvidedRequiredArgumentsRule.js <==
var jsutils_inspect = require("../../jsutils/inspect.js");

var jsutils_keyMap = require("../../jsutils/keyMap.js");

var type_definition = require("../../type/definition.js");

var type_directives = require("../../type/directives.js");

var shared = require("../../shared.js");

function ProvidedRequiredArgumentsOnDirectivesRule(context) {
  var _schema$getDirectives;
  const requiredArgsMap = Object.create(null);
  const schema = context.getSchema();
  const definedDirectives = null !== (_schema$getDirectives = null == schema ? void 0 : schema.getDirectives()) && void 0 !== _schema$getDirectives ? _schema$getDirectives : type_directives.specifiedDirectives;
  for (const directive of definedDirectives) {
    requiredArgsMap[directive.name] = jsutils_keyMap.keyMap(directive.args.filter(type_definition.isRequiredArgument), (arg => arg.name));
  }
  const astDefinitions = context.getDocument().definitions;
  for (const def of astDefinitions) {
    if (def.kind === shared.e.DIRECTIVE_DEFINITION) {
      var _def$arguments;
      const argNodes = null !== (_def$arguments = def.arguments) && void 0 !== _def$arguments ? _def$arguments : [];
      requiredArgsMap[def.name.value] = jsutils_keyMap.keyMap(argNodes.filter(isRequiredArgumentNode), (arg => arg.name.value));
    }
  }
  return {
    Directive: {
      leave(directiveNode) {
        const directiveName = directiveNode.name.value;
        const requiredArgs = requiredArgsMap[directiveName];
        if (requiredArgs) {
          var _directiveNode$argume;
          const argNodes = null !== (_directiveNode$argume = directiveNode.arguments) && void 0 !== _directiveNode$argume ? _directiveNode$argume : [];
          const argNodeMap = new Set(argNodes.map((arg => arg.name.value)));
          for (const [argName, argDef] of Object.entries(requiredArgs)) {
            if (!argNodeMap.has(argName)) {
              const argType = type_definition.isType(argDef.type) ? jsutils_inspect.inspect(argDef.type) : shared.print(argDef.type);
              context.reportError(new shared.GraphQLError(`Directive "@${directiveName}" argument "${argName}" of type "${argType}" is required, but it was not provided.`, {
                nodes: directiveNode
              }));
            }
          }
        }
      }
    }
  };
}

function isRequiredArgumentNode(arg) {
  return arg.type.kind === shared.e.NON_NULL_TYPE && null == arg.defaultValue;
}

exports.ProvidedRequiredArgumentsOnDirectivesRule = ProvidedRequiredArgumentsOnDirectivesRule;

exports.ProvidedRequiredArgumentsRule = function ProvidedRequiredArgumentsRule(context) {
  return {
    ...ProvidedRequiredArgumentsOnDirectivesRule(context),
    Field: {
      leave(fieldNode) {
        var _fieldNode$arguments;
        const fieldDef = context.getFieldDef();
        if (!fieldDef) {
          return !1;
        }
        const providedArgs = new Set(null === (_fieldNode$arguments = fieldNode.arguments) || void 0 === _fieldNode$arguments ? void 0 : _fieldNode$arguments.map((arg => arg.name.value)));
        for (const argDef of fieldDef.args) {
          if (!providedArgs.has(argDef.name) && type_definition.isRequiredArgument(argDef)) {
            const argTypeStr = jsutils_inspect.inspect(argDef.type);
            context.reportError(new shared.GraphQLError(`Field "${fieldDef.name}" argument "${argDef.name}" of type "${argTypeStr}" is required, but it was not provided.`, {
              nodes: fieldNode
            }));
          }
        }
      }
    }
  };
};

==> graphql-web-lite-16.6.0-4.tgz: package/validation/rules/ProvidedRequiredArgumentsRule.js <==
var jsutils_inspect = require("../../jsutils/inspect.js");

var jsutils_keyMap = require("../../jsutils/keyMap.js");

var type_definition = require("../../type/definition.js");

var type_directives = require("../../type/directives.js");

var graphql_web = require("@0no-co/graphql.web");

function ProvidedRequiredArgumentsOnDirectivesRule(context) {
  var _schema$getDirectives;
  const requiredArgsMap = Object.create(null);
  const schema = context.getSchema();
  const definedDirectives = null !== (_schema$getDirectives = null == schema ? void 0 : schema.getDirectives()) && void 0 !== _schema$getDirectives ? _schema$getDirectives : type_directives.specifiedDirectives;
  for (const directive of definedDirectives) {
    requiredArgsMap[directive.name] = jsutils_keyMap.keyMap(directive.args.filter(type_definition.isRequiredArgument), (arg => arg.name));
  }
  const astDefinitions = context.getDocument().definitions;
  for (const def of astDefinitions) {
    if (def.kind === graphql_web.Kind.DIRECTIVE_DEFINITION) {
      var _def$arguments;
      const argNodes = null !== (_def$arguments = def.arguments) && void 0 !== _def$arguments ? _def$arguments : [];
      requiredArgsMap[def.name.value] = jsutils_keyMap.keyMap(argNodes.filter(isRequiredArgumentNode), (arg => arg.name.value));
    }
  }
  return {
    Directive: {
      leave(directiveNode) {
        const directiveName = directiveNode.name.value;
        const requiredArgs = requiredArgsMap[directiveName];
        if (requiredArgs) {
          var _directiveNode$argume;
          const argNodes = null !== (_directiveNode$argume = directiveNode.arguments) && void 0 !== _directiveNode$argume ? _directiveNode$argume : [];
          const argNodeMap = new Set(argNodes.map((arg => arg.name.value)));
          for (const [argName, argDef] of Object.entries(requiredArgs)) {
            if (!argNodeMap.has(argName)) {
              const argType = type_definition.isType(argDef.type) ? jsutils_inspect.inspect(argDef.type) : graphql_web.print(argDef.type);
              context.reportError(new graphql_web.GraphQLError(`Directive "@${directiveName}" argument "${argName}" of type "${argType}" is required, but it was not provided.`, {
                nodes: directiveNode
              }));
            }
          }
        }
      }
    }
  };
}

function isRequiredArgumentNode(arg) {
  return arg.type.kind === graphql_web.Kind.NON_NULL_TYPE && null == arg.defaultValue;
}

exports.ProvidedRequiredArgumentsOnDirectivesRule = ProvidedRequiredArgumentsOnDirectivesRule;

exports.ProvidedRequiredArgumentsRule = function ProvidedRequiredArgumentsRule(context) {
  return {
    ...ProvidedRequiredArgumentsOnDirectivesRule(context),
    Field: {
      leave(fieldNode) {
        var _fieldNode$arguments;
        const fieldDef = context.getFieldDef();
        if (!fieldDef) {
          return !1;
        }
        const providedArgs = new Set(null === (_fieldNode$arguments = fieldNode.arguments) || void 0 === _fieldNode$arguments ? void 0 : _fieldNode$arguments.map((arg => arg.name.value)));
        for (const argDef of fieldDef.args) {
          if (!providedArgs.has(argDef.name) && type_definition.isRequiredArgument(argDef)) {
            const argTypeStr = jsutils_inspect.inspect(argDef.type);
            context.reportError(new graphql_web.GraphQLError(`Field "${fieldDef.name}" argument "${argDef.name}" of type "${argTypeStr}" is required, but it was not provided.`, {
              nodes: fieldNode
            }));
          }
        }
      }
    }
  };
};
